==> wordpress-1.5.1-da_DK.tar.gz: wordpress/wp.php <==
﻿<?php
// Dette er et eksempel på en meget simpel skabelon
require_once('./wp-blog-header.php');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
"http://www.w3.org/TR/xhtml/DTD/xhtml-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
	<title><?php bloginfo('name'); ?><?php wp_title(); ?></title>
	<meta http-equiv="Content-Type" content="<?php bloginfo('html_type'); ?>; charset=<?php echo get_settings('blog_charset'); ?>" />
	<meta name="generator" content="WordPress <?php $wp_version ?>" /> <!-- lad dette blive så vi kan lave statistik -->
	<link rel="alternate" type="text/xml" title="RSS" href="<?php bloginfo('rss2_url'); ?>" />
	<link rel="pingback" href="<?php bloginfo('pingback_url'); ?>" />
</head>
<body>
<h1 id="header"><a href="<?php echo get_settings('home'); ?>" title="<?php bloginfo('name'); ?>"><?php bloginfo('name'); ?></a></h1>

<!-- // loop start -->
<?php if (have_posts()) : while (have_posts()) : the_post(); ?>
<?php the_date('d.m.y', '<h2>','</h2>'); ?>
<h3 id="post-<?php the_ID(); ?>"><a href="<?php the_permalink() ?>" rel="bookmark" title="Permanent link: <?php the_title(); ?>"><?php the_title(); ?></a></h3>

<?php the_content(); ?>

<?php link_pages('<br />Sider: ', '<br />', 'number') ?>

<p><em>Skrevet af <strong><?php the_author() ?></strong> @ <a href="<?php the_permalink() ?>"><?php the_time() ?></a></em></p>
<p>Gemt i: <?php the_category(',') ?></p>

<?php comments_popup_link('kommentarer?', '1 kommentar', '% kommentarer') ?>

<?php comments_template(); ?>


<!-- // dette er bare slutningen af motoren - det skal du heller ikke røre ved :) -->
<?php endwhile; else: ?>
<p><?php _e('Sorry, no posts matched your criteria.'); ?></p>
<?php endif; ?>

<div align="right"><cite>Drevet af <a href="http://wordpress.org"><strong>Wordpress</strong></a></cite><br />
<br />
<a href="wp-login.php">Log ind</a><br />
<a href="wp-register.php">Registrer</a>
</div>


</body>
</html>

==> wordpress-1.5.1.2-da_DK.tar.gz: wordpress/wp.php <==
<?php
// Dette er et eksempel p en meget simpel skabelon
require_once('./wp-blog-header.php');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
"http://www.w3.org/TR/xhtml/DTD/xhtml-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
	<title><?php bloginfo('name'); ?><?php wp_title(); ?></title>
	<meta http-equiv="Content-Type" content="<?php bloginfo('html_type'); ?>; charset=<?php echo get_settings('blog_charset'); ?>" />
	<meta name="generator" content="WordPress <?php $wp_version ?>" /> <!-- lad dette st s vi kan lave statistik -->
	<link rel="alternate" type="text/xml" title="RSS" href="<?php bloginfo('rss2_url'); ?>" />
	<link rel="pingback" href="<?php bloginfo('pingback_url'); ?>" />
</head>
<body>
<h1 id="header"><a href="<?php echo get_settings('home'); ?>" title="<?php bloginfo('name'); ?>"><?php bloginfo('name'); ?></a></h1>

<!-- // loop start -->
<?php if (have_posts()) : while (have_posts()) : the_post(); ?>
<?php the_date('d.m.y', '<h2>','</h2>'); ?>
<h3 id="post-<?php the_ID(); ?>"><a href="<?php the_permalink() ?>" rel="bookmark" title="Permanent link: <?php the_title(); ?>"><?php the_title(); ?></a></h3>

<?php the_content(); ?>

<?php link_pages('<br />Sider: ', '<br />', 'number') ?>

<p><em>Skrevet af <strong><?php the_author() ?></strong> @ <a href="<?php the_permalink() ?>"><?php the_time() ?></a></em></p>
<p>Gemt i: <?php the_category(',') ?></p>

<?php comments_popup_link('kommentarer?', '1 kommentar', '% kommentarer') ?>

<?php comments_template(); ?>


<!-- // dette er bare slutningen af motoren - det skal du heller ikke rre ved :) -->
<?php endwhile; else: ?>
<p><?php _e('Der var desvrre ingen indlg, der matcher dine sgekriterier.'); ?></p>
<?php endif; ?>

<div align="right"><cite>Drevet af <a href="http://wordpress.org"><strong>Wordpress</strong></a></cite><br />
<br />
<a href="wp-login.php">Log ind</a><br />
<a href="wp-register.php">Registrer</a>
</div>


</body>
</html>
